@@ -47,6 +47,16 @@ for db_table, disj in pairs(dnfs) do
         redis.call('sadd', conj_key, key)
         -- NOTE: an invalidator should live longer than any key it references.
         --       So we update its ttl on every key if needed.
+        -- REDIS_7
         redis.call('expire', conj_key, timeout, 'gt')
+        -- /REDIS_7
+        -- REDIS_6
+        local conj_ttl = redis.call('ttl', conj_key)
+        if conj_ttl < timeout then
+            -- We set conj_key life with a margin over key life to call expire rarer
+            -- And add few extra seconds to be extra safe
+            redis.call('expire', conj_key, timeout * 2 + 10)
+        end
+        -- /REDIS_6
     end
 end
